==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/aa-ER/validation.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines contain the default error messages used by
    | the validator class. Some of these rules have multiple versions such
    | such as the size rules. Feel free to tweak each of these messages.
    |
    */

    'accepted' => 'crwdns12328:0crwdne12328:0',
    'accepted_if' => 'crwdns12330:0crwdne12330:0',
    'active_url' => 'crwdns12332:0crwdne12332:0',
    'after' => 'crwdns12334:0crwdne12334:0',
    'after_or_equal' => 'crwdns12336:0crwdne12336:0',
    'alpha' => 'crwdns12338:0crwdne12338:0',
    'alpha_dash' => 'crwdns12340:0crwdne12340:0',
    'alpha_num' => 'crwdns12342:0crwdne12342:0',
    'array' => 'crwdns12344:0crwdne12344:0',
    'ascii' => 'crwdns12346:0crwdne12346:0',
    'before' => 'crwdns12348:0crwdne12348:0',
    'before_or_equal' => 'crwdns12350:0crwdne12350:0',
    'between' => [
        'array' => 'crwdns12352:0crwdne12352:0',
        'file' => 'crwdns12354:0crwdne12354:0',
        'numeric' => 'crwdns12356:0crwdne12356:0',
        'string' => 'crwdns12358:0crwdne12358:0',
    ],
    'boolean' => 'crwdns12360:0crwdne12360:0',
    'can' => 'crwdns12362:0crwdne12362:0',
    'confirmed' => 'crwdns12364:0crwdne12364:0',
    'contains' => 'crwdns12366:0crwdne12366:0',
    'current_password' => 'crwdns12368:0crwdne12368:0',
    'date' => 'crwdns12370:0crwdne12370:0',
    'date_equals' => 'crwdns12372:0crwdne12372:0',
    'date_format' => 'crwdns12374:0crwdne12374:0',
    'decimal' => 'crwdns12376:0crwdne12376:0',
    'declined' => 'crwdns12378:0crwdne12378:0',
    'declined_if' => 'crwdns12380:0crwdne12380:0',
    'different' => 'crwdns12382:0crwdne12382:0',
    'digits' => 'crwdns12384:0crwdne12384:0',
    'digits_between' => 'crwdns12386:0crwdne12386:0',
    'dimensions' => 'crwdns12388:0crwdne12388:0',
    'distinct' => 'crwdns1926:0crwdne1926:0',
    'doesnt_end_with' => 'crwdns12390:0crwdne12390:0',
    'doesnt_start_with' => 'crwdns12392:0crwdne12392:0',
    'email' => 'crwdns12394:0crwdne12394:0',
    'ends_with' => 'crwdns12396:0crwdne12396:0',
    'enum' => 'crwdns12398:0crwdne12398:0',
    'exists' => 'crwdns990:0crwdne990:0',
    'extensions' => 'crwdns12400:0crwdne12400:0',
    'file' => 'crwdns12402:0crwdne12402:0',
    'filled' => 'crwdns1928:0crwdne1928:0',
    'gt' => [
        'array' => 'crwdns12404:0crwdne12404:0',
        'file' => 'crwdns12406:0crwdne12406:0',
        'numeric' => 'crwdns12408:0crwdne12408:0',
        'string' => 'crwdns12410:0crwdne12410:0',
    ],
    'gte' => [
        'array' => 'crwdns12412:0crwdne12412:0',
        'file' => 'crwdns12414:0crwdne12414:0',
        'numeric' => 'crwdns12416:0crwdne12416:0',
        'string' => 'crwdns12418:0crwdne12418:0',
    ],
    'hex_color' => 'crwdns12420:0crwdne12420:0',
    'image' => 'crwdns12422:0crwdne12422:0',
    'import_field_empty'    => 'crwdns11191:0crwdne11191:0',
    'in' => 'crwdns992:0crwdne992:0',
    'in_array' => 'crwdns12424:0crwdne12424:0',
    'integer' => 'crwdns12426:0crwdne12426:0',
    'ip' => 'crwdns12428:0crwdne12428:0',
    'ipv4' => 'crwdns12430:0crwdne12430:0',
    'ipv6' => 'crwdns12432:0crwdne12432:0',
    'json' => 'crwdns12434:0crwdne12434:0',
    'list' => 'crwdns12436:0crwdne12436:0',
    'lowercase' => 'crwdns12438:0crwdne12438:0',
    'lt' => [
        'array' => 'crwdns12440:0crwdne12440:0',
        'file' => 'crwdns12442:0crwdne12442:0',
        'numeric' => 'crwdns12444:0crwdne12444:0',
        'string' => 'crwdns12446:0crwdne12446:0',
    ],
    'lte' => [
        'array' => 'crwdns12448:0crwdne12448:0',
        'file' => 'crwdns12450:0crwdne12450:0',
        'numeric' => 'crwdns12452:0crwdne12452:0',
        'string' => 'crwdns12454:0crwdne12454:0',
    ],
    'mac_address' => 'crwdns12456:0crwdne12456:0',
    'max' => [
        'array' => 'crwdns12458:0crwdne12458:0',
        'file' => 'crwdns12460:0crwdne12460:0',
        'numeric' => 'crwdns12462:0crwdne12462:0',
        'string' => 'crwdns12464:0crwdne12464:0',
    ],
    'max_digits' => 'crwdns12466:0crwdne12466:0',
    'mimes' => 'crwdns12468:0crwdne12468:0',
    'mimetypes' => 'crwdns12470:0crwdne12470:0',
    'min' => [
        'array' => 'crwdns12472:0crwdne12472:0',
        'file' => 'crwdns12474:0crwdne12474:0',
        'numeric' => 'crwdns12476:0crwdne12476:0',
        'string' => 'crwdns12478:0crwdne12478:0',
    ],
    'min_digits' => 'crwdns12480:0crwdne12480:0',
    'missing' => 'crwdns12482:0crwdne12482:0',
    'missing_if' => 'crwdns12484:0crwdne12484:0',
    'missing_unless' => 'crwdns12486:0crwdne12486:0',
    'missing_with' => 'crwdns12488:0crwdne12488:0',
    'missing_with_all' => 'crwdns12490:0crwdne12490:0',
    'multiple_of' => 'crwdns12492:0crwdne12492:0',
    'not_in' => 'crwdns1002:0crwdne1002:0',
    'not_regex' => 'crwdns12494:0crwdne12494:0',
    'numeric' => 'crwdns12496:0crwdne12496:0',
    'password' => [
        'letters' => 'crwdns12498:0crwdne12498:0',
        'mixed' => 'crwdns12500:0crwdne12500:0',
        'numbers' => 'crwdns12502:0crwdne12502:0',
        'symbols' => 'crwdns12504:0crwdne12504:0',
        'uncompromised' => 'crwdns12506:0crwdne12506:0',
    ],
    'present' => 'crwdns1936:0crwdne1936:0',
    'present_if' => 'crwdns12508:0crwdne12508:0',
    'present_unless' => 'crwdns12510:0crwdne12510:0',
    'present_with' => 'crwdns12512:0crwdne12512:0',
    'present_with_all' => 'crwdns12514:0crwdne12514:0',
    'prohibited' => 'crwdns12516:0crwdne12516:0',
    'prohibited_if' => 'crwdns12518:0crwdne12518:0',
    'prohibited_unless' => 'crwdns12520:0crwdne12520:0',
    'prohibits' => 'crwdns12522:0crwdne12522:0',
    'regex' => 'crwdns12524:0crwdne12524:0',
    'required' => 'crwdns1005:0crwdne1005:0',
    'required_array_keys' => 'crwdns12526:0crwdne12526:0',
    'required_if' => 'crwdns1006:0crwdne1006:0',
    'required_if_accepted' => 'crwdns12528:0crwdne12528:0',
    'required_if_declined' => 'crwdns12530:0crwdne12530:0',
    'required_unless' => 'crwdns1937:0crwdne1937:0',
    'required_with' => 'crwdns1007:0crwdne1007:0',
    'required_with_all' => 'crwdns12532:0crwdne12532:0',
    'required_without' => 'crwdns1008:0crwdne1008:0',
    'required_without_all' => 'crwdns1939:0crwdne1939:0',
    'same' => 'crwdns12534:0crwdne12534:0',
    'size' => [
        'array' => 'crwdns12536:0crwdne12536:0',
        'file' => 'crwdns12538:0crwdne12538:0',
        'numeric' => 'crwdns12540:0crwdne12540:0',
        'string' => 'crwdns12542:0crwdne12542:0',
    ],
    'starts_with' => 'crwdns12544:0crwdne12544:0',
    'string'               => 'crwdns1941:0crwdne1941:0',
    'two_column_unique_undeleted' => 'crwdns11892:0crwdne11892:0',
    'unique_undeleted'     => 'crwdns1964:0crwdne1964:0',
    'non_circular'         => 'crwdns6070:0crwdne6070:0',
    'not_array'            => 'crwdns12056:0crwdne12056:0',
    'disallow_same_pwd_as_user_fields' => 'crwdns10498:0crwdne10498:0',
    'letters'              => 'crwdns10500:0crwdne10500:0',
    'numbers'              => 'crwdns10502:0crwdne10502:0',
    'case_diff'            => 'crwdns10504:0crwdne10504:0',
    'symbols'              => 'crwdns10506:0crwdne10506:0',
    'timezone' => 'crwdns12546:0crwdne12546:0',
    'unique' => 'crwdns1013:0crwdne1013:0',
    'uploaded' => 'crwdns1943:0crwdne1943:0',
    'uppercase' => 'crwdns12548:0crwdne12548:0',
    'url' => 'crwdns12550:0crwdne12550:0',
    'ulid' => 'crwdns12552:0crwdne12552:0',
    'uuid' => 'crwdns12554:0crwdne12554:0',

    /*
    |--------------------------------------------------------------------------
    | Custom Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | Here you may specify custom validation messages for attributes using the
    | convention "attribute.rule" to name the lines. This makes it quick to
    | specify a specific custom language line for a given attribute rule.
    |
    */

    'custom' => [
        'alpha_space' => 'crwdns1944:0crwdne1944:0',
        'email_array'      => 'crwdns1945:0crwdne1945:0',
        'hashed_pass'      => 'crwdns1946:0crwdne1946:0',
        'dumbpwd'          => 'crwdns1947:0crwdne1947:0',
        'statuslabel_type' => 'crwdns1948:0crwdne1948:0',

        // date_format validation with slightly less stupid messages. It duplicates a lot, but it gets the job done :(
        // We use this because the default error message for date_format is reflects php Y-m-d, which non-PHP
        // people won't know how to format.
        'purchase_date.date_format'     => 'crwdns11247:0crwdne11247:0',
        'last_audit_date.date_format'   =>  'crwdns11249:0crwdne11249:0',
        'expiration_date.date_format'   =>  'crwdns11251:0crwdne11251:0',
        'termination_date.date_format'  =>  'crwdns11253:0crwdne11253:0',
        'expected_checkin.date_format'  =>  'crwdns11255:0crwdne11255:0',
        'start_date.date_format'        =>  'crwdns11257:0crwdne11257:0',
        'end_date.date_format'          =>  'crwdns11259:0crwdne11259:0',
        'checkboxes'           => 'crwdns12556:0crwdne12556:0',
        'radio_buttons'        => 'crwdns12558:0crwdne12558:0',
        'invalid_value_in_field' => 'crwdns12560:0crwdne12560:0',
        ],
    /*
    |--------------------------------------------------------------------------
    | Custom Validation Attributes
    |--------------------------------------------------------------------------
    |
    | The following language lines are used to swap attribute place-holders
    | with something more reader friendly such as E-Mail Address instead
    | of "email". This simply helps us make messages a little cleaner.
    |
    */

    'attributes' => [],

    /*
    |--------------------------------------------------------------------------
    | Generic Validation Messages - we use these in the jquery validation where we don't have
    | access to the :attribute
    |--------------------------------------------------------------------------
    */

    'generic' => [
        'invalid_value_in_field' => 'crwdns12580:0crwdne12580:0',
        'required' => 'crwdns12582:0crwdne12582:0',
        'email' => 'crwdns12584:0crwdne12584:0',
    ],


];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/aa-ER/validation.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines contain the default error messages used by
    | the validator class. Some of these rules have multiple versions such
    | such as the size rules. Feel free to tweak each of these messages.
    |
    */

    'accepted' => 'crwdns12328:0crwdne12328:0',
    'accepted_if' => 'crwdns12330:0crwdne12330:0',
    'active_url' => 'crwdns12332:0crwdne12332:0',
    'after' => 'crwdns12334:0crwdne12334:0',
    'after_or_equal' => 'crwdns12336:0crwdne12336:0',
    'alpha' => 'crwdns12338:0crwdne12338:0',
    'alpha_dash' => 'crwdns12340:0crwdne12340:0',
    'alpha_num' => 'crwdns12342:0crwdne12342:0',
    'array' => 'crwdns12344:0crwdne12344:0',
    'ascii' => 'crwdns12346:0crwdne12346:0',
    'before' => 'crwdns12348:0crwdne12348:0',
    'before_or_equal' => 'crwdns12350:0crwdne12350:0',
    'between' => [
        'array' => 'crwdns12352:0crwdne12352:0',
        'file' => 'crwdns12354:0crwdne12354:0',
        'numeric' => 'crwdns12356:0crwdne12356:0',
        'string' => 'crwdns12358:0crwdne12358:0',
    ],
    'boolean' => 'crwdns12360:0crwdne12360:0',
    'can' => 'crwdns12362:0crwdne12362:0',
    'confirmed' => 'crwdns12364:0crwdne12364:0',
    'contains' => 'crwdns12366:0crwdne12366:0',
    'current_password' => 'crwdns12368:0crwdne12368:0',
    'date' => 'crwdns12370:0crwdne12370:0',
    'date_equals' => 'crwdns12372:0crwdne12372:0',
    'date_format' => 'crwdns12374:0crwdne12374:0',
    'decimal' => 'crwdns12376:0crwdne12376:0',
    'declined' => 'crwdns12378:0crwdne12378:0',
    'declined_if' => 'crwdns12380:0crwdne12380:0',
    'different' => 'crwdns12382:0crwdne12382:0',
    'digits' => 'crwdns12384:0crwdne12384:0',
    'digits_between' => 'crwdns12386:0crwdne12386:0',
    'dimensions' => 'crwdns12388:0crwdne12388:0',
    'distinct' => 'crwdns1926:0crwdne1926:0',
    'doesnt_end_with' => 'crwdns12390:0crwdne12390:0',
    'doesnt_start_with' => 'crwdns12392:0crwdne12392:0',
    'email' => 'crwdns12394:0crwdne12394:0',
    'ends_with' => 'crwdns12396:0crwdne12396:0',
    'enum' => 'crwdns12398:0crwdne12398:0',
    'exists' => 'crwdns990:0crwdne990:0',
    'extensions' => 'crwdns12400:0crwdne12400:0',
    'file' => 'crwdns12402:0crwdne12402:0',
    'filled' => 'crwdns1928:0crwdne1928:0',
    'gt' => [
        'array' => 'crwdns12404:0crwdne12404:0',
        'file' => 'crwdns12406:0crwdne12406:0',
        'numeric' => 'crwdns12408:0crwdne12408:0',
        'string' => 'crwdns12410:0crwdne12410:0',
    ],
    'gte' => [
        'array' => 'crwdns12412:0crwdne12412:0',
        'file' => 'crwdns12414:0crwdne12414:0',
        'numeric' => 'crwdns12416:0crwdne12416:0',
        'string' => 'crwdns12418:0crwdne12418:0',
    ],
    'hex_color' => 'crwdns12420:0crwdne12420:0',
    'image' => 'crwdns12422:0crwdne12422:0',
    'import_field_empty'    => 'crwdns11191:0crwdne11191:0',
    'in' => 'crwdns992:0crwdne992:0',
    'in_array' => 'crwdns12424:0crwdne12424:0',
    'integer' => 'crwdns12426:0crwdne12426:0',
    'ip' => 'crwdns12428:0crwdne12428:0',
    'ipv4' => 'crwdns12430:0crwdne12430:0',
    'ipv6' => 'crwdns12432:0crwdne12432:0',
    'json' => 'crwdns12434:0crwdne12434:0',
    'list' => 'crwdns12436:0crwdne12436:0',
    'lowercase' => 'crwdns12438:0crwdne12438:0',
    'lt' => [
        'array' => 'crwdns12440:0crwdne12440:0',
        'file' => 'crwdns12442:0crwdne12442:0',
        'numeric' => 'crwdns12444:0crwdne12444:0',
        'string' => 'crwdns12446:0crwdne12446:0',
    ],
    'lte' => [
        'array' => 'crwdns12448:0crwdne12448:0',
        'file' => 'crwdns12450:0crwdne12450:0',
        'numeric' => 'crwdns12452:0crwdne12452:0',
        'string' => 'crwdns12454:0crwdne12454:0',
    ],
    'mac_address' => 'crwdns12456:0crwdne12456:0',
    'max' => [
        'array' => 'crwdns12458:0crwdne12458:0',
        'file' => 'crwdns12460:0crwdne12460:0',
        'numeric' => 'crwdns12462:0crwdne12462:0',
        'string' => 'crwdns12464:0crwdne12464:0',
    ],
    'max_digits' => 'crwdns12466:0crwdne12466:0',
    'mimes' => 'crwdns12468:0crwdne12468:0',
    'mimetypes' => 'crwdns12470:0crwdne12470:0',
    'min' => [
        'array' => 'crwdns12472:0crwdne12472:0',
        'file' => 'crwdns12474:0crwdne12474:0',
        'numeric' => 'crwdns12476:0crwdne12476:0',
        'string' => 'crwdns12478:0crwdne12478:0',
    ],
    'min_digits' => 'crwdns12480:0crwdne12480:0',
    'missing' => 'crwdns12482:0crwdne12482:0',
    'missing_if' => 'crwdns12484:0crwdne12484:0',
    'missing_unless' => 'crwdns12486:0crwdne12486:0',
    'missing_with' => 'crwdns12488:0crwdne12488:0',
    'missing_with_all' => 'crwdns12490:0crwdne12490:0',
    'multiple_of' => 'crwdns12492:0crwdne12492:0',
    'not_in' => 'crwdns1002:0crwdne1002:0',
    'not_regex' => 'crwdns12494:0crwdne12494:0',
    'numeric' => 'crwdns12496:0crwdne12496:0',
    'password' => [
        'letters' => 'crwdns12498:0crwdne12498:0',
        'mixed' => 'crwdns12500:0crwdne12500:0',
        'numbers' => 'crwdns12502:0crwdne12502:0',
        'symbols' => 'crwdns12504:0crwdne12504:0',
        'uncompromised' => 'crwdns12506:0crwdne12506:0',
    ],
    'percent'       => 'crwdns12660:0crwdne12660:0',

    'present' => 'crwdns1936:0crwdne1936:0',
    'present_if' => 'crwdns12508:0crwdne12508:0',
    'present_unless' => 'crwdns12510:0crwdne12510:0',
    'present_with' => 'crwdns12512:0crwdne12512:0',
    'present_with_all' => 'crwdns12514:0crwdne12514:0',
    'prohibited' => 'crwdns12516:0crwdne12516:0',
    'prohibited_if' => 'crwdns12518:0crwdne12518:0',
    'prohibited_unless' => 'crwdns12520:0crwdne12520:0',
    'prohibits' => 'crwdns12522:0crwdne12522:0',
    'regex' => 'crwdns12524:0crwdne12524:0',
    'required' => 'crwdns1005:0crwdne1005:0',
    'required_array_keys' => 'crwdns12526:0crwdne12526:0',
    'required_if' => 'crwdns1006:0crwdne1006:0',
    'required_if_accepted' => 'crwdns12528:0crwdne12528:0',
    'required_if_declined' => 'crwdns12530:0crwdne12530:0',
    'required_unless' => 'crwdns1937:0crwdne1937:0',
    'required_with' => 'crwdns1007:0crwdne1007:0',
    'required_with_all' => 'crwdns12532:0crwdne12532:0',
    'required_without' => 'crwdns1008:0crwdne1008:0',
    'required_without_all' => 'crwdns1939:0crwdne1939:0',
    'same' => 'crwdns12534:0crwdne12534:0',
    'size' => [
        'array' => 'crwdns12536:0crwdne12536:0',
        'file' => 'crwdns12538:0crwdne12538:0',
        'numeric' => 'crwdns12540:0crwdne12540:0',
        'string' => 'crwdns12542:0crwdne12542:0',
    ],
    'starts_with' => 'crwdns12544:0crwdne12544:0',
    'string'               => 'crwdns1941:0crwdne1941:0',
    'two_column_unique_undeleted' => 'crwdns11892:0crwdne11892:0',
    'unique_undeleted'     => 'crwdns1964:0crwdne1964:0',
    'non_circular'         => 'crwdns6070:0crwdne6070:0',
    'not_array'            => 'crwdns12056:0crwdne12056:0',
    'disallow_same_pwd_as_user_fields' => 'crwdns10498:0crwdne10498:0',
    'letters'              => 'crwdns10500:0crwdne10500:0',
    'numbers'              => 'crwdns10502:0crwdne10502:0',
    'case_diff'            => 'crwdns10504:0crwdne10504:0',
    'symbols'              => 'crwdns10506:0crwdne10506:0',
    'timezone' => 'crwdns12546:0crwdne12546:0',
    'unique' => 'crwdns1013:0crwdne1013:0',
    'uploaded' => 'crwdns1943:0crwdne1943:0',
    'uppercase' => 'crwdns12548:0crwdne12548:0',
    'url' => 'crwdns12550:0crwdne12550:0',
    'ulid' => 'crwdns12552:0crwdne12552:0',
    'uuid' => 'crwdns12554:0crwdne12554:0',


    /*
    |--------------------------------------------------------------------------
    | Custom Validation Language Lines
    |--------------------------------------------------------------------------
    |
    | Here you may specify custom validation messages for attributes using the
    | convention "attribute.rule" to name the lines. This makes it quick to
    | specify a specific custom language line for a given attribute rule.
    |
    */

    'custom' => [
        'alpha_space' => 'crwdns1944:0crwdne1944:0',
        'email_array'      => 'crwdns1945:0crwdne1945:0',
        'hashed_pass'      => 'crwdns1946:0crwdne1946:0',
        'dumbpwd'          => 'crwdns1947:0crwdne1947:0',
        'statuslabel_type' => 'crwdns1948:0crwdne1948:0',
        'custom_field_not_found'          => 'crwdns12650:0crwdne12650:0',
        'custom_field_not_found_on_model' => 'crwdns12652:0crwdne12652:0',

        // date_format validation with slightly less stupid messages. It duplicates a lot, but it gets the job done :(
        // We use this because the default error message for date_format reflects php Y-m-d, which non-PHP
        // people won't know how to format.
        'purchase_date.date_format'     => 'crwdns11247:0crwdne11247:0',
        'last_audit_date.date_format'   =>  'crwdns11249:0crwdne11249:0',
        'expiration_date.date_format'   =>  'crwdns11251:0crwdne11251:0',
        'termination_date.date_format'  =>  'crwdns11253:0crwdne11253:0',
        'expected_checkin.date_format'  =>  'crwdns11255:0crwdne11255:0',
        'start_date.date_format'        =>  'crwdns11257:0crwdne11257:0',
        'end_date.date_format'          =>  'crwdns11259:0crwdne11259:0',
        'checkboxes'           => 'crwdns12556:0crwdne12556:0',
        'radio_buttons'        => 'crwdns12558:0crwdne12558:0',
        'invalid_value_in_field' => 'crwdns12560:0crwdne12560:0',

        'ldap_username_field' => [
            'not_in' =>         'crwdns12762:0crwdne12762:0'
        ],
        'ldap_auth_filter_query' => ['not_in' => 'crwdns12764:0crwdne12764:0'],
        'ldap_filter' => ['regex' => 'crwdns12766:0crwdne12766:0'],

        ],
    /*
    |--------------------------------------------------------------------------
    | Custom Validation Attributes
    |--------------------------------------------------------------------------
    |
    | The following language lines are used to swap attribute place-holders
    | with something more reader friendly such as E-Mail Address instead
    | of "email". This simply helps us make messages a little cleaner.
    |
    */

    'attributes' => [],

    /*
    |--------------------------------------------------------------------------
    | Generic Validation Messages - we use these in the jquery validation where we don't have
    | access to the :attribute
    |--------------------------------------------------------------------------
    */

    'generic' => [
        'invalid_value_in_field' => 'crwdns12580:0crwdne12580:0',
        'required' => 'crwdns12582:0crwdne12582:0',
        'email' => 'crwdns12584:0crwdne12584:0',
    ],


];
